@@ -2,6 +2,7 @@
   * Axel -- A lighter download accelerator for Linux and other Unices. *
   *                                                                    *
   * Copyright 2001 Wilmer van der Gaast                                *
+  * Copyright 2015 Joao Eriberto Mota Filho                            *
   \********************************************************************/
 
 /* Text interface							*/
@@ -276,12 +277,12 @@ int main( int argc, char *argv[] )
 			}
 		}
 		sprintf( string, "%s.st", fn );
-		if( access( fn, F_OK ) == 0 ) if( access( string, F_OK ) != 0 )
+		if( access( fn, F_OK ) == 0 && access( string, F_OK ) != 0 )
 		{
 			fprintf( stderr, _("No state file, cannot resume!\n") );
 			return( 1 );
 		}
-		if( access( string, F_OK ) == 0 ) if( access( fn, F_OK ) != 0 )
+		if( access( string, F_OK ) == 0 && access( fn, F_OK ) != 0 )
 		{
 			printf( _("State file found, but no downloaded data. Starting from scratch.\n" ) );
 			unlink( string );
@@ -435,14 +436,14 @@ void stop( int signal )
 /* Convert a number of bytes to a human-readable form			*/
 char *size_human( long long int value )
 {
-	if( value == 1 )
+	if( value < 1024 )
 		sprintf( string, _("%lld byte"), value );
-	else if( value < 1024 )
-		sprintf( string, _("%lld bytes"), value );
-	else if( value < 10485760 )
-		sprintf( string, _("%.1f kilobytes"), (float) value / 1024 );
+	else if( value < 1024 * 1024 )
+		sprintf( string, _("%.1f Kilobyte"), (float) value / 1024 );
+	else if( value < 1024 * 1024 * 1024 )
+		sprintf( string, _("%.1f Megabyte"), (float) value / (1024 * 1024) );
 	else
-		sprintf( string, _("%.1f megabytes"), (float) value / 1048576 );
+		sprintf( string, _("%.1f Gigabyte"), (float) value / (1024 * 1024 * 1024) );
 	
 	return( string );
 }
@@ -455,9 +456,9 @@ char *time_human( int value )
 	else if( value < 60 )
 		sprintf( string, _("%i seconds"), value );
 	else if( value < 3600 )
-		sprintf( string, _("%i:%02i seconds"), value / 60, value % 60 );
+		sprintf( string, _("%i:%02i minute(s)"), value / 60, value % 60 );
 	else
-		sprintf( string, _("%i:%02i:%02i seconds"), value / 3600, ( value / 60 ) % 60, value % 60 );
+		sprintf( string, _("%i:%02i:%02i hour(s)"), value / 3600, ( value / 60 ) % 60, value % 60 );
 	
 	return( string );
 }
@@ -552,7 +553,7 @@ void print_help()
 		"-h\tThis information\n"
 		"-V\tVersion information\n"
 		"\n"
-		"Visit http://axel.alioth.debian.org/ to report bugs\n") );
+		"Visit https://github.com/eribertomota/axel/issues\n") );
 #else
 	printf(	_("Usage: axel [options] url1 [url2] [url...]\n"
 		"\n"
@@ -569,14 +570,17 @@ void print_help()
 		"--help\t\t\t-h\tThis information\n"
 		"--version\t\t-V\tVersion information\n"
 		"\n"
-		"Visit http://axel.alioth.debian.org/ to report bugs\n") );
+		"Visit https://github.com/eribertomota/axel/issues to report bugs\n") );
 #endif
 }
 
 void print_version()
 {
-	printf( _("Axel version %s (%s)\n"), AXEL_VERSION_STRING, ARCH );
-	printf( "\nCopyright 2001-2002 Wilmer van der Gaast.\n" );
+	printf( _("\nAxel version %s (%s)\n"), AXEL_VERSION_STRING, ARCH );
+	printf( "\nCopyright 2001-2007 Wilmer van der Gaast," );
+	printf( "\n          2015      Joao Eriberto Mota Filho," );
+	printf( "\n                    and others." );
+	printf ("\nPlease, see the CREDITS file.\n\n" );
 }
 
 /* Print any message in the axel structure				*/
